==> flink-1.15.0-src.tgz: flink-1.15.0/flink-table/flink-table-planner/src/test/scala/org/apache/flink/table/planner/plan/batch/table/PythonGroupWindowAggregateTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.plan.batch.table

import org.apache.flink.api.scala._
import org.apache.flink.table.api._
import org.apache.flink.table.planner.runtime.utils.JavaUserDefinedAggFunctions.{PandasAggregateFunction, TestPythonAggregateFunction}
import org.apache.flink.table.planner.utils.TableTestBase

import org.junit.Test

class PythonGroupWindowAggregateTest extends TableTestBase {

  @Test
  def testPandasEventTimeTumblingGroupWindowOverTime(): Unit = {
    val util = batchTestUtil()
    val sourceTable = util.addTableSource[(Int, Long, Int, Long)](
      "MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Tumble over 5.millis on 'rowtime as 'w)
      .groupBy('w, 'b)
      .select('b, 'w.start,'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test(expected = classOf[TableException])
  def testPandasEventTimeTumblingGroupWindowOverCount(): Unit = {
    val util = batchTestUtil()
    val sourceTable = util.addTableSource[(Int, Long, Int, Long)](
      "MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Tumble over 2.rows on 'rowtime as 'w)
      .groupBy('w, 'b)
      .select('b, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test
  def testPandasEventTimeSlidingGroupWindowOverTime(): Unit = {
    val util = batchTestUtil()
    val sourceTable = util.addTableSource[(Int, Long, Int, Long)](
      "MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Slide over 5.millis every 2.millis on 'rowtime as 'w)
      .groupBy('w, 'b)
      .select('b, 'w.start,'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test(expected = classOf[TableException])
  def testPandasEventTimeSlidingGroupWindowOverCount(): Unit = {
    val util = batchTestUtil()
    val sourceTable = util.addTableSource[(Int, Long, Int, Long)](
      "MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Slide over 5.rows every 2.rows on 'rowtime as 'w)
      .groupBy('w, 'b)
      .select('b, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test
  def testPandasGroupWindowAggregateWithoutKeys(): Unit = {
    val util = batchTestUtil()
    val sourceTable = util.addTableSource[(Int, Long, Int, Long)](
      "MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Slide over 5.millis every 2.millis on 'rowtime as 'w)
      .groupBy('w)
      .select('w.start,'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test(expected = classOf[TableException])
  def testGeneralEventTimeTumblingGroupWindowOverTime(): Unit = {
    val util = batchTestUtil()
    val sourceTable = util.addTableSource[(Int, Long, Int, Long)](
      "MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new TestPythonAggregateFunction

    val resultTable = sourceTable
      .window(Tumble over 5.millis on 'rowtime as 'w)
      .groupBy('w, 'b)
      .select('b, 'w.start,'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }
}

==> flink-1.18.1-src.tgz: flink-1.18.1/flink-table/flink-table-planner/src/test/scala/org/apache/flink/table/planner/plan/batch/table/PythonGroupWindowAggregateTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.table.planner.plan.batch.table

import org.apache.flink.api.scala._
import org.apache.flink.table.api._
import org.apache.flink.table.planner.runtime.utils.JavaUserDefinedAggFunctions.{PandasAggregateFunction, TestPythonAggregateFunction}
import org.apache.flink.table.planner.utils.TableTestBase

import org.junit.Test

class PythonGroupWindowAggregateTest extends TableTestBase {

  @Test
  def testPandasEventTimeTumblingGroupWindowOverTime(): Unit = {
    val util = batchTestUtil()
    val sourceTable =
      util.addTableSource[(Int, Long, Int, Long)]("MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Tumble.over(5.millis).on('rowtime).as('w))
      .groupBy('w, 'b)
      .select('b, 'w.start, 'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test(expected = classOf[TableException])
  def testPandasEventTimeTumblingGroupWindowOverCount(): Unit = {
    val util = batchTestUtil()
    val sourceTable =
      util.addTableSource[(Int, Long, Int, Long)]("MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Tumble.over(2.rows).on('rowtime).as('w))
      .groupBy('w, 'b)
      .select('b, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test
  def testPandasEventTimeSlidingGroupWindowOverTime(): Unit = {
    val util = batchTestUtil()
    val sourceTable =
      util.addTableSource[(Int, Long, Int, Long)]("MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Slide.over(5.millis).every(2.millis).on('rowtime).as('w))
      .groupBy('w, 'b)
      .select('b, 'w.start, 'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test(expected = classOf[TableException])
  def testPandasEventTimeSlidingGroupWindowOverCount(): Unit = {
    val util = batchTestUtil()
    val sourceTable =
      util.addTableSource[(Int, Long, Int, Long)]("MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Slide.over(5.rows).every(2.rows).on('rowtime).as('w))
      .groupBy('w, 'b)
      .select('b, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test
  def testPandasGroupWindowAggregateWithoutKeys(): Unit = {
    val util = batchTestUtil()
    val sourceTable =
      util.addTableSource[(Int, Long, Int, Long)]("MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new PandasAggregateFunction

    val resultTable = sourceTable
      .window(Slide.over(5.millis).every(2.millis).on('rowtime).as('w))
      .groupBy('w)
      .select('w.start, 'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }

  @Test(expected = classOf[TableException])
  def testGeneralEventTimeTumblingGroupWindowOverTime(): Unit = {
    val util = batchTestUtil()
    val sourceTable =
      util.addTableSource[(Int, Long, Int, Long)]("MyTable", 'a, 'b, 'c, 'rowtime.rowtime)
    val func = new TestPythonAggregateFunction

    val resultTable = sourceTable
      .window(Tumble.over(5.millis).on('rowtime).as('w))
      .groupBy('w, 'b)
      .select('b, 'w.start, 'w.end, func('a, 'c))

    util.verifyExecPlan(resultTable)
  }
}
